@@ -22,7 +22,7 @@ using System;
 using System.IO;
 using System.Collections;
 
-using Mono.Posix;
+using Mono.Unix;
 
 using Gtk;
 
@@ -49,15 +49,12 @@ namespace Muine
 			Catalog.GetString ("_Import Folder...");
 
 		private static readonly string string_open =
-			Catalog.GetString ("_Open Playlist...");
+			Catalog.GetString ("_Open...");
 
 		private static readonly string string_save =
-			Catalog.GetString ("_Save Playlist As...");
+			Catalog.GetString ("_Save As...");
 
-		private static readonly string string_toggle_visible_hide =
-			Catalog.GetString ("Hide _Window");
-
-		private static readonly string string_toggle_visible_show =
+		private static readonly string string_toggle_visible =
 			Catalog.GetString ("Show _Window");
 
 		// Strings :: Menu :: Song
@@ -65,7 +62,7 @@ namespace Muine
 			Catalog.GetString ("_Play");
 
 		private static readonly string string_previous =
-			Catalog.GetString ("_Previous");
+			Catalog.GetString ("P_revious");
 
 		private static readonly string string_next =
 			Catalog.GetString ("_Next");
@@ -130,9 +127,6 @@ namespace Muine
 			new ActionEntry ("Save", Stock.SaveAs, string_save,
 				"<shift><control>S", null, null),
 
-			new ActionEntry ("ToggleVisible", null, "", // string set dynamically
-				"Escape", null, null),
-
 			new ActionEntry ("Quit", Stock.Quit, null,
 				"<control>Q", null, null),
 			
@@ -154,7 +148,7 @@ namespace Muine
 			new ActionEntry ("PlaySong", Stock.Add, string_play_song,
 				"S", null, null),
 
-			new ActionEntry ("PlayAlbum", "gnome-dev-cdrom-audio", string_play_album,
+			new ActionEntry ("PlayAlbum", "stock_music-library", string_play_album,
 				"A", null, null),
 
 			new ActionEntry ("Remove", Stock.Remove, string_remove,
@@ -164,7 +158,7 @@ namespace Muine
 				"<control>Delete", null, null),
 
 			new ActionEntry ("Clear", Stock.Clear, string_clear,
-				null, null, null),
+				"<control>L", null, null),
 
 			new ActionEntry ("Shuffle", "stock_shuffle", string_shuffle,
 				"<control>S", null, null),
@@ -180,33 +174,12 @@ namespace Muine
 
 			new ToggleActionEntry ("ToggleRepeat", null, string_toggle_repeat,
 			       "<control>R", null, null, false),
+
+			new ToggleActionEntry ("ToggleVisible", null, string_toggle_visible,
+				"Escape", null, null, true),
+
 		};
 
-		// Static :: Properties
-		// Static :: Properties :: StringToggleVisibleHide (get;)
-		/// <summary>
-		/// 	The translated string used for the toggle visible
-		/// 	action when the window is currently shown.
-		/// </summary>
-		/// <returns>
-		///	A translated <see cref="String" />.
-		/// </return>
-		public static string StringToggleVisibleHide {
-			get { return string_toggle_visible_hide; }
-		}
-
-		// Static :: Properties :: StringToggleVisibleShow (get;)
-		/// <summary>
-		/// 	The translated string used for the toggle visible
-		/// 	action when the window is currently hidden.
-		/// </summary>
-		/// <returns>
-		///	A translated <see cref="String" />.
-		/// </return>
-		public static string StringToggleVisibleShow {
-			get { return string_toggle_visible_show; }
-		}
-		
 		// Static :: Properties :: Entries (get;)
 		/// <summary>
 		/// 	The defined actions.
@@ -363,7 +336,13 @@ namespace Muine
 		/// </param>
 		private void OnToggleVisible (object o, EventArgs args)
 		{
-			Global.Playlist.ToggleVisible ();
+			ToggleAction a = (ToggleAction) o;
+
+			if (a.Active == Global.Playlist.Visible)
+				return;
+
+			Global.Playlist.SetWindowVisible (!Global.Playlist.WindowVisible,
+                                                          Gtk.Global.CurrentEventTime);
 		}
 
 		// Handlers :: OnQuit
@@ -489,7 +468,7 @@ namespace Muine
 		/// </param>
 		private void OnPlaySong (object o, EventArgs args)
 		{
-			Global.Playlist.PlaySong ();
+			Global.Playlist.PlaySong (Gtk.Global.CurrentEventTime);
 		}
 
 		// Handlers :: OnPlayAlbum
@@ -507,7 +486,7 @@ namespace Muine
 		/// </param>
 		private void OnPlayAlbum (object o, EventArgs args)
 		{
-			Global.Playlist.PlayAlbum ();
+			Global.Playlist.PlayAlbum (Gtk.Global.CurrentEventTime);
 		}
 
 		// Handlers :: OnRemove
