@@ -26,7 +26,7 @@ using Gdk;
 
 using DBus;
 
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Muine
 {
@@ -109,9 +109,7 @@ namespace Muine
 		/// </param>
 		public static void Main (string [] args)
 		{
-			Catalog.Init ("muine", Defines.GNOME_LOCALE_DIR);
-
-			new Gnome.Program ("muine", Defines.VERSION, Gnome.Modules.UI, args);
+			Application.Init ();
 
 			// Try to find a running Muine
 			try {
@@ -126,13 +124,20 @@ namespace Muine
 				if (args.Length > 0)
 					ProcessCommandLine (args);
 				else
-					dbus_object.SetWindowVisible (true);
+					dbus_object.SetWindowVisible (true, 0);
 				
 				Gdk.Global.NotifyStartupComplete ();
 
+				// Nasty hack to fix problem with incorrectly generated IL in dbus-sharp. Idea from abock in
+				// banshee.
+				System.GC.SuppressFinalize(dbus_object);
 				return;
 			}
 
+			Catalog.Init ("muine", Defines.GNOME_LOCALE_DIR);
+
+			new Gnome.Program ("muine", Defines.VERSION, Gnome.Modules.UI, args);
+
 			// Initialize D-Bus
 			//	We initialize here but don't connect to it until later.
 			try {
